Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1023)

Unified Diff: Source/core/html/HTMLObjectElement.cpp

Issue 931003002: Move and rename RenderPart to LayoutPart. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLObjectElement.h ('k') | Source/core/html/HTMLPlugInElement.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLObjectElement.cpp
diff --git a/Source/core/html/HTMLObjectElement.cpp b/Source/core/html/HTMLObjectElement.cpp
index f2cb385f23985e76a27c5b9e757785ad0addad9e..df2061788be2c27e11ae555b6e5ced04e235fe9e 100644
--- a/Source/core/html/HTMLObjectElement.cpp
+++ b/Source/core/html/HTMLObjectElement.cpp
@@ -75,9 +75,9 @@ void HTMLObjectElement::trace(Visitor* visitor)
HTMLPlugInElement::trace(visitor);
}
-RenderPart* HTMLObjectElement::existingRenderPart() const
+LayoutPart* HTMLObjectElement::existingLayoutPart() const
{
- return renderPart(); // This will return 0 if the renderer is not a RenderPart.
+ return layoutPart(); // This will return 0 if the renderer is not a LayoutPart.
}
bool HTMLObjectElement::isPresentationAttribute(const QualifiedName& name) const
« no previous file with comments | « Source/core/html/HTMLObjectElement.h ('k') | Source/core/html/HTMLPlugInElement.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698